@@ -3,8 +3,8 @@
 ;; Copyright (C) 2025  lizqwer scott
 
 ;; Author: lizqwer scott <lizqwerscott@gmail.com>
-;; Package-Version: 20251219.314
-;; Package-Revision: 125e0a4478ff
+;; Package-Version: 20260121.452
+;; Package-Revision: 2e947d2ddc8c
 ;; Package-Requires: ((emacs "30.1") (jsonrpc "1.0.25"))
 ;; Keywords: tools
 ;; URL: https://github.com/lizqwerscott/mcp.el
@@ -137,7 +137,13 @@ Available levels:
    (-roots
     :initarg :roots
     :initform nil
-    :accessor mcp--roots))
+    :accessor mcp--roots)
+   (-timeout
+    :initarg :timeout
+    :initform nil
+    :accessor mcp--timeout
+    :documentation "Timeout in seconds for jsonrpc async requests.
+When nil, uses `jsonrpc-default-request-timeout'."))
   :documentation "A MCP connection over an Emacs process.")
 
 (defclass mcp-http-process-connection (mcp-process-connection)
@@ -751,6 +757,7 @@ SYNCP specifies if the operation should be synchronous or asynchronous."
 
 ;;;###autoload
 (cl-defun mcp-connect-server (name &key command args url env token headers roots
+                                   timeout
                                    initial-callback tools-callback prompts-callback
                                    resources-callback resources-templates-callback
                                    error-callback syncp)
@@ -776,6 +783,9 @@ Each root can be either:
   (e.g., (:uri \"file:///home/user/project\" :name \"Project\"))
 Roots define filesystem boundaries that the server can access.
 
+TIMEOUT is the timeout in seconds for jsonrpc async requests.
+Defaults to `jsonrpc-default-request-timeout' when nil.
+
 INITIAL-CALLBACK is a function called when the server completes
 the connection.
 TOOLS-CALLBACK is a function called to handle the list of tools
@@ -839,6 +849,7 @@ in the `mcp-server-connections` hash table for future reference."
                                   :name ,name
                                   :process ,process
                                   :roots ,roots
+                                  :timeout ,(or timeout jsonrpc-default-request-timeout)
                                   :events-buffer-config (:size ,mcp-log-size)
                                   :request-dispatcher ,(lambda (_ method params)
                                                          (funcall #'mcp-request-dispatcher name method params))
@@ -1029,6 +1040,7 @@ See `mcp-async-set-log-level' and `mcp-sync-set-log-level'."
          (args `(,connection
                  :logging/setLevel
                  ,(list :level (format "%s" log-level))
+                 :timeout ,(mcp--timeout connection)
                  ,@(unless syncp `(:success-fn
                                    ,success-fn))
                  ,@(unless syncp `(:error-fn
@@ -1091,6 +1103,7 @@ On error, it displays an error message with the code from the server."
   (jsonrpc-async-request connection
                          :ping
                          nil
+                         :timeout (mcp--timeout connection)
                          :success-fn
                          (lambda (res)
                            (message "[mcp] ping success: %s" res))
@@ -1203,6 +1216,7 @@ SYNCP specifies if the operation should be synchronous or asynchronous."
                                 (jsonrpc-name connection) code message))))
          (args `(,connection
                  ,method nil
+                 :timeout ,(mcp--timeout connection)
                  ,@(unless syncp `(:success-fn
                                    ,success-fn))
                  ,@(unless syncp `(:error-fn
@@ -1259,6 +1273,7 @@ ERROR-CALLBACK is a function to call on error."
                                :arguments (if arguments
                                               arguments
                                             #s(hash-table)))
+                         :timeout (mcp--timeout connection)
                          :success-fn
                          (lambda (res)
                            (funcall callback res))
@@ -1305,6 +1320,7 @@ ERROR-CALLBACK is a function to call on error."
                                :arguments (if arguments
                                               arguments
                                             #s(hash-table)))
+                         :timeout (mcp--timeout connection)
                          :success-fn
                          (lambda (res)
                            (funcall callback res))
@@ -1347,6 +1363,7 @@ succeeds, or ERROR-CALLBACK if it fails."
   (jsonrpc-async-request connection
                          :resources/read
                          (list :uri uri)
+                         :timeout (mcp--timeout connection)
                          :success-fn
                          (lambda (res)
                            (funcall callback res))
